@@ -32,11 +32,31 @@ g.part4 = function(datadir = c(), metadatadir = c(), f0 = f0, f1 = f1,
     dolog = FALSE
   }
   if (dolog == TRUE) {
-    logs_diaries = g.loadlog(params_sleep[["loglocation"]], coln1 = params_sleep[["coln1"]], colid = params_sleep[["colid"]],
-                             meta.sleep.folder = meta.sleep.folder,
-                             desiredtz = params_general[["desiredtz"]])
-    sleeplog = logs_diaries$sleeplog
-    save(logs_diaries, file = paste0(metadatadir,"/meta/sleeplog.RData"))
+    sleeplogRDataFile = paste0(metadatadir,"/meta/sleeplog_", basename(params_sleep[["loglocation"]]), ".RData")
+    # only re-process sleeplog if sleeplog.RData does not exist or if sleeplog
+    # is from a date equal to or after sleeplog.RData
+    if (!file.exists(sleeplogRDataFile) || 
+        file.info(params_sleep[["loglocation"]])$mtime >= file.info(sleeplogRDataFile)$mtime) {
+      logs_diaries = g.loadlog(params_sleep[["loglocation"]], 
+                               coln1 = params_sleep[["coln1"]],
+                               colid = params_sleep[["colid"]],
+                               meta.sleep.folder = meta.sleep.folder,
+                               desiredtz = params_general[["desiredtz"]])
+      save(logs_diaries, file = sleeplogRDataFile)
+    } else {
+      load(file = sleeplogRDataFile)
+    }
+    if (params_sleep[["sleepwindowType"]] == "TimeInBed" && length(logs_diaries$bedlog) > 0) {
+      sleeplog = logs_diaries$bedlog
+    } else {
+      sleeplog = logs_diaries$sleeplog
+    }
+    sleeplog$night = as.numeric(sleeplog$night)
+    sleeplog$duration = as.numeric(sleeplog$duration)
+    if (is.null(logs_diaries$sleeplog) && is.null(logs_diaries$bedlog)) {
+      dolog = FALSE
+      rm(sleeplog)
+    }
   }
   #------------------------------------------------
   # get list of accelerometer milestone data files from sleep (produced by g.part3)
@@ -363,7 +383,7 @@ g.part4 = function(datadir = c(), metadatadir = c(), f0 = f0, f1 = f1,
           acc_available = TRUE  #default assumption
           # initialize dataframe to hold sleep period overview:
           spocum = data.frame(nb = numeric(0), start = numeric(0),  end = numeric(0),
-                              dur = numeric(0), def = character(0))
+                              overlapGuider = numeric(0), def = character(0))
           
           spocumi = 1  # counter for sleep periods
           # continue now with the specific data of the night
@@ -613,25 +633,33 @@ g.part4 = function(datadir = c(), metadatadir = c(), f0 = f0, f1 = f1,
                 # spo is now a data.frame of start and end for each sib (sustained inactivity bout)
                 # Classify as being part of the guider window or not
                 for (evi in 1:nrow(spo)) {
-                  if (spo$start[evi] < GuiderWake & spo$end[evi] > GuiderOnset) {
-                    if (params_sleep[["sleepwindowType"]] == "TimeInBed") {
-                      if (spo$end[evi] < GuiderWake & spo$start[evi] > GuiderOnset) {
-                        # if using a time in bed reference, then sleep can never 
-                        # start before time in bed
-                        spo$overlapGuider[evi] = 1  #All sib that start after guider onset and end before guider wake
+                  if (spo$start[evi] < GuiderWake && spo$end[evi] > GuiderOnset) {
+                    if (params_sleep[["sleepwindowType"]] == "TimeInBed" &&
+                        sum(params_sleep[["sib_must_fully_overlap_with_TimeInBed"]]) != 0) {
+                      if (all(params_sleep[["sib_must_fully_overlap_with_TimeInBed"]]) &&
+                          spo$start[evi] > GuiderOnset && spo$end[evi] < GuiderWake) {
+                        spo$overlapGuider[evi] = 1  # Consider only full overlap
+                      }
+                      if (all(params_sleep[["sib_must_fully_overlap_with_TimeInBed"]] == c(FALSE, TRUE)) &&
+                          spo$end[evi] < GuiderWake) {
+                        spo$overlapGuider[evi] = 1 # Consider only full overlap
+                      }
+                      if (all(params_sleep[["sib_must_fully_overlap_with_TimeInBed"]] == c(TRUE, FALSE)) &&
+                          spo$start[evi] > GuiderOnset) {
+                        spo$overlapGuider[evi] = 1  # Consider only full overlap
                       }
                     } else {
-                      spo$overlapGuider[evi] = 1  # All sib that end after guider onset and start before guider wake
+                      spo$overlapGuider[evi] = 1  # Consider partial overlap
                     }
                     if (params_sleep[["relyonguider"]] == TRUE | relyonguider_thisnight == TRUE) {
                       # Redefine sib start and end if it overlaps with guider
                       # to match guider 
-                      if ((spo$start[evi] < GuiderWake & spo$end[evi] > GuiderWake) |
-                          (spo$start[evi] < GuiderWake & spo$end[evi] < spo$start[evi])) {
+                      if ((spo$start[evi] < GuiderWake && spo$end[evi] > GuiderWake) |
+                          (spo$start[evi] < GuiderWake && spo$end[evi] < spo$start[evi])) {
                         spo$end[evi] = GuiderWake
                       }
-                      if ((spo$start[evi] < GuiderOnset & spo$end[evi] > GuiderOnset) |
-                          (spo$end[evi] > GuiderOnset & spo$end[evi] < spo$start[evi])) {
+                      if ((spo$start[evi] < GuiderOnset && spo$end[evi] > GuiderOnset) |
+                          (spo$end[evi] > GuiderOnset && spo$end[evi] < spo$start[evi])) {
                         spo$start[evi] = GuiderOnset
                       }
                     }
@@ -730,7 +758,6 @@ g.part4 = function(datadir = c(), metadatadir = c(), f0 = f0, f1 = f1,
                   }
                   delta_t1 = diff(as.numeric(spocum.t$end))
                   spocum.t$overlapGuider = correct01010pattern(spocum.t$overlapGuider)
-                  
                   #----------------------------
                   nightsummary[sumi, 1] = accid
                   nightsummary[sumi, 2] = j  #night
