@@ -2,7 +2,7 @@ library(GGIR)
 context("getfolderstructure")
 test_that("getfolderstructure", {
   dn = "A" # name of the datadir folder
-  if (file.exists(dn))  unlink(dn,recursive=TRUE)
+  if (file.exists(dn)) unlink(dn, recursive = TRUE)
   dummyfolderA = "A"
   dummyfolderB = "B"
   dummyfolderC = "C"
@@ -10,11 +10,14 @@ test_that("getfolderstructure", {
   dir.create(file.path("A/B"))
   dir.create(file.path("A/C"))
   
-  write.csv(matrix(0,4,4),file="A/B/testB.csv")
-  write.csv(matrix(0,4,4),file="A/C/testC.csv")
+  write.csv(matrix(0, 4, 4), file = "A/B/testB.csv")
+  write.csv(matrix(0, 4, 4), file = "A/C/testC.csv")
   
-  folderstructure = getfolderstructure(datadir=dn,referencefnames=c("testB.csv","testC.csv"))
+  folderstructure = getfolderstructure(datadir = dn,
+                                       referencefnames = c("testB.csv", "testC.csv"))
   expect_that(  folderstructure$foldername[1],equals("B"))
   expect_that(  folderstructure$foldername[2],equals("C"))
-  if (file.exists(dn))  unlink(dn,recursive=TRUE)
+  if (file.exists(dn))
+    unlink(dn, recursive = TRUE
+    )
 })
\ No newline at end of file
